<?php
/*
Plugin Name: Shopp Cache Helper
Description: Helps Shopp play nicer with caches. Currently designed for W3 Total Cache, but should work on other caches too.
- Sets a cookie whenever the cart is updated. If the cart becomes empty the cookie is purged. NOTE: some browsers systems leave the cookie around with the value of 'deleted', you might need to hack your cache software to check for this value and treat it as an empty cookie. (The worst that could happen is that caching is disabled longer than necessary - no big deal.)
- Clears the cache when product, category etc. details are changed.
TODO: Options!!!
Author: Tyson LT
Version: 0.2
*/

define('SHOPP_CACHE_HELPER_COOKIE_NAME', 'shopp_items_in_cart');
define('SHOPP_CACHE_HELPER_PLUS_TIME', 3600);
define('SHOPP_CACHE_HELPER_MINUS_TIME', 41932800);

/**
 * Called when a user adds or removes an item from the cart.
 *
 * Sets a cookie that can be used to tell caching plugins to stop caching.
 */
function shopp_cache_helper_cart_updated($cart) {

  //cart updated, check for contents
  if (count($cart->contents) > 0) {
 
    //set cookie to tell cache manager to go dynamic
    setcookie(SHOPP_CACHE_HELPER_COOKIE_NAME, SHOPP_CACHE_HELPER_COOKIE_NAME, time() + SHOPP_CACHE_HELPER_PLUS_TIME, "/");

  } else {

    //safe to remove cookie, cart is empty
    setcookie(SHOPP_CACHE_HELPER_COOKIE_NAME, '', time() - SHOPP_CACHE_HELPER_MINUS_TIME, "/");

    //also clear cache now in case cart was cached somehow (PARANOID)
    if (function_exists('w3tc_pgcache_flush')) {
      w3tc_pgcache_flush();
    }

  }

}

/**
 * Called whenever any data is changed in the shopp backend.
 *
 * Clears the cache to refresh products, categories, and settings.
 */
function shopp_cache_helper_data_changed() {

    //flush w3tc page cache
    if (function_exists('w3tc_pgcache_flush')) {
      w3tc_pgcache_flush();
    }

}

//setup the actions
add_action('shopp_cart_updated',   'shopp_cache_helper_cart_updated'); 

add_action('shopp_product_saved',  'shopp_cache_helper_data_changed'); 
add_action('shopp_category_saved', 'shopp_cache_helper_data_changed'); 
add_action('shopp_promo_saved',    'shopp_cache_helper_data_changed'); 
add_action('shopp_category_saved', 'shopp_cache_helper_data_changed'); 
add_action('add_product_download', 'shopp_cache_helper_data_changed'); 

?>